@@ -7,7 +7,8 @@ import string
 from rich.console import Console
 import subprocess
 from dotenv import find_dotenv
-from typing import Dict
+from typing import Dict, Union
+from collections import OrderedDict
 
 from doing.exceptions import ConfigurationError, devops_error_tips
 
@@ -86,7 +87,7 @@ def get_repo_name():
     return repo_name
 
 
-def get_config(key: str = "", fallback: str = None, envvar_prefix: str = "DOING_CONFIG_"):
+def get_config(key: str = "", fallback: Union[str, Dict] = None, envvar_prefix: str = "DOING_CONFIG_"):
     """
     Finds and reads doing configuration file.
 
@@ -166,7 +167,11 @@ def run_command(command: str, allow_verbose=True):
 
     if process.returncode != 0:
         console.print(f"[bright_black]{command}[/bright_black]")
-        console.print(f"[dark_orange3]{str(process.stderr)}[/dark_orange3]")
+        if process.stdout:
+            console.print(f"[dark_orange3]{str(process.stdout)}[/dark_orange3]")
+        if process.stderr:
+            console.print(f"[dark_orange3]{str(process.stderr)}[/dark_orange3]")
+
         # Help the user
         devops_error_tips(str(process.stderr))
         sys.exit(process.returncode)
@@ -205,11 +210,23 @@ def define_env(env):
 def replace_user_aliases(text: str) -> str:
     """
     Replace alias with emailadres in a string.
+
+    User aliases are defined under 'user_aliases' in the .doing-cli.config.yml file.
+    Additionally, the @me alias point to current user.
     """
     words = text.split()
-    aliases = get_config("user_aliases", "")
+    words = list(OrderedDict.fromkeys(words))  # deduplicate keeping ordering
 
-    if not len(aliases):
-        return text
+    aliases = get_config("user_aliases", {})
 
-    return " ".join([aliases.get(word, word) for word in words])
+    # If the user is logged in, replace the @me alias
+    # Otherwise, just move on. Helps with unit testing on CI.
+    try:
+        aliases["@me"] = get_az_devop_user_email()
+    except Exception:
+        pass
+
+    if not aliases:
+        return " ".join(words)
+    else:
+        return " ".join([aliases.get(word, word) for word in words])
